/**********************************************************
*
*       Copyright (c) 1994 Pixel Semiconductor, Inc.  All rights reserved.
*
*       File Name: PXTUNER.C
*
*       Module Abstract:
*       ----------------
*       Controls a Philips Tuner, model FI1236
*       or TIMIC tuner.
*
***********************************************************
*
*       Author: Gary Peterson
*       Date:   08-04-94
*
*       Revision History:
*       -----------------
*       WHO             WHEN            WHAT/WHY/HOW
*       ---             ----            ------------
*       Gene Shaw       3/10/97         Linux Stuff
*
**********************************************************/


/*
 *   Include Files.
 */

#include <stdio.h>
#include <string.h>

#include "i2capi.h"
#include "pxtapi.h"

#define PXTUNER_H
#include "pxtuner.h"
#undef  PXTUNER_H


/*
 *   Function Prototypes.
 */
int ioInitTuner(void);
int tnrTunerWrite(unsigned char *ucTuner,
                  unsigned char ucNumberBytes,
                  unsigned char ucAddress,
                  unsigned char ucSubAddress,
                  unsigned char ucAddressOption);
int tnrTunerRead(unsigned char *ucTuner,
                 unsigned char ucNumberBytes,
                 unsigned char ucAddress,
                 unsigned char ucSubAddress,
                 unsigned char ucAddressOption);




/**********************************************************
*
*       Name:  ioInitTuner
*
*       Module Abstract:
*       ----------------
*       This function initializes the tuner.
*
*       Input Parameters:
*       -----------------
*       hInstance       - Library instance handle.
*       wDataSegment    - Data Segment register value.
*       wHeapSize       - Number of bytes in the heap.
*       lpszCommandLine - Pointer to command line variables.
*
*       Output Parameters:
*       ------------------
*       DLL load status - TRUE = Loaded, FALSE = Aborted.
*
*       Global Variables:
*       -----------------
*
***********************************************************
*
*       Author: Gary Peterson
*       Date:   08-04-94
*
*       Revision History:
*       -----------------
*       WHO             WHEN     WHAT/WHY/HOW
*       ---             ----     ------------
*
*********************************************************/

int ioInitTuner()
{
   static unsigned char ucTuner[5];
   int           iRet;

   /*
    *   Setup initial tuner values.
    */
   ucTuner[ADDRESS_BYTE]     = TUNER_WRITE_ADDRESS;
   ucTuner[DIVIDER_BYTE0]    = DEFAULT_CHANNEL_HI_BYTE;
   ucTuner[DIVIDER_BYTE1]    = DEFAULT_CHANNEL_LOW_BYTE;
   ucTuner[CHARGE_PUMP_CTRL] = DEFAULT_CHARGE_PUMP;
   ucTuner[OUTPUT_PORT_CTRL] = DEFAULT_FREQ_BAND;

   /*
    *   Write only the four data bytes to the tuner. Don't write
    *   the address byte, because the tuner always responds to
    *   address 0xC2.
    */
   iRet = tnrTunerWrite(&ucTuner[DIVIDER_BYTE0],
			0x04,
			TUNER_WRITE_ADDRESS,
			0x01,
			ADDRESSUSED);

   /*
    *   Check return code.
    */
   if(iRet == TNR_ERR)
   {
      /*
       *   Tuner write failed.
       */
/*      MessageBeep(MB_OK); */
   }

  return (iRet);
}


/**********************************************************
*
*       Function Name: tnrReadChannelStatus
*
*       Module Abstract:
*       ----------------
*       Read the status byte in the tuner to decide
*       whether the channel is good or not.
*
*       Input Parameters:
*       -----------------
*       Pointer to unsigned char.

*       Output Parameters:
*       ------------------
*       Success = TNR_OK, Fail = TNR_ERR.
*
*       Global Variables:
*       -----------------
*       None
*
***********************************************************
*
*       Author: Frank Xu
*       Date:   08-30-94
*
*       Revision History:
*       -----------------
*       WHO             WHEN            WHAT/WHY/HOW
*       ---             ----            ------------
*
*********************************************************/

int tnrReadChannelStatus(char *lpTunerStatus)
{
   int           iRet;
   unsigned char bTunerStatus;

   /*
    *   Get the tuner status out from bTunerStatus
    */
   bTunerStatus = 0;
   iRet = tnrTunerRead ((unsigned char *)&bTunerStatus, 1, TUNER_READ_ADDRESS, 0, ADDRESSUSED);

   /*
    *   Check return code.
    */
   if(iRet == TNR_ERR)
   {
      return TNR_ERR;
   }

   /* Assign back to formal parameter */
   *lpTunerStatus = bTunerStatus;
   return TNR_OK;
}

/**********************************************************
*
*       Function Name: tnrChangeChannel
*
*       Module Abstract:
*       ----------------
*       Decides what band the channel is in,
*       and writes the info to the Philips Tuner,
*       model FI1236.
*
*       Input Parameters:
*       -----------------
*       fChanFreq  - Channel frequency value.
*       cFineTune  - The number (+ or -) of 62.5 KHz steps
*                    to shift the channel frequency by.
*       fPictureIF - Picture intermediate frequency value.
*
*       Output Parameters:
*       ------------------
*       Success = TNR_OK, Fail = TNR_ERR.
*
*       Global Variables:
*       -----------------
*       None
*
***********************************************************
*
*       Author: Gary Peterson - Adapted from Dan Davis
*       Date:   08-04-94
*
*       Revision History:
*       -----------------
*       WHO             WHEN            WHAT/WHY/HOW
*       ---             ----            ------------
*
*********************************************************/

int tnrChangeChannel(float *fChanFreq,
					char  cFineTune,
					float *fPictureIF)
{
   static unsigned char ucTuner[5];
   unsigned int         uiDivisorValue;
   int                  iRet;

   printf("Change channel to %f\n",*fChanFreq);

#if TIMIC
   if((fChanFreq >= 55.25) && (fChanFreq <= 157.25))
   {
      ucTuner[OUTPUT_PORT_CTRL] = LOW_FREQ_BAND;
   }
   else if((fChanFreq >= 163.25) && (fChanFreq <= 463.25))
   {
      ucTuner[OUTPUT_PORT_CTRL] = MID_FREQ_BAND;
   }
   else if((fChanFreq >= 469.25) && (fChanFreq <= 801.25))
   {
      ucTuner[OUTPUT_PORT_CTRL] = HIGH_FREQ_BAND;
   }
   else
   {
      return (int) TNR_ERR;
   }
#else
   if(((float)*fChanFreq >= (float) 54.00) && ((float)*fChanFreq <= (float) 157.25))
   {
      ucTuner[OUTPUT_PORT_CTRL] = LOW_FREQ_BAND;
   }
   else if((*fChanFreq >= 162.00) && (*fChanFreq <= 451.25))
   {
      ucTuner[OUTPUT_PORT_CTRL] = MID_FREQ_BAND;
   }
   else if((*fChanFreq >= 456.00) && (*fChanFreq <= 801.25))
   {
      ucTuner[OUTPUT_PORT_CTRL] = HIGH_FREQ_BAND;
   }
   else
   {
      return TNR_ERR;
   }
#endif

   uiDivisorValue = (unsigned int) (16 * (*fChanFreq + *fPictureIF) + cFineTune);

   ucTuner[DIVIDER_BYTE0] = (unsigned char)(uiDivisorValue >> 8);
   ucTuner[DIVIDER_BYTE1] = (unsigned char)(uiDivisorValue & 0x00FF);

   /*
    *   The charge pump value doesn't change.
    */
   ucTuner[CHARGE_PUMP_CTRL] = DEFAULT_CHARGE_PUMP;

   /*
    *   Send the results to the tuner.
    */
   iRet = tnrTunerWrite(&ucTuner[DIVIDER_BYTE0],
                        0x04,
                        TUNER_WRITE_ADDRESS,
                        0x00,
                        ADDRESSUSED);

   /*
    *   Check return code.
    */
   if(iRet == TNR_ERR)
   {
      return (int) TNR_ERR;
   }

   return (int) TNR_OK;
}

/**********************************************************
*
*       Function Name: tnrTunerWrite
*
*       Module Abstract:
*       ----------------
*       Write information to the Philips Tuner, model FI1236.
*
*       Input Parameters:
*       -----------------
*       *ucTuner
*       ucNumberBytes
*       ucAddress
*       ucSubAddress
*       ucAddressOption
*
*       Output Parameters:
*       ------------------
*       Success = TNR_OK, Fail = TNR_ERR.
*
*       Global Variables:
*       -----------------
*       None
*
***********************************************************
*
*       Author: Gary Peterson - Adapted from Dan Davis
*       Date:   08-04-94
*
*       Revision History:
*       -----------------
*       WHO             WHEN            WHAT/WHY/HOW
*       ---             ----            ------------
*
*********************************************************/

int tnrTunerWrite(unsigned char *ucTuner,
                  unsigned char ucNumberBytes,
                  unsigned char ucAddress,
                  unsigned char ucSubAddress,
                  unsigned char ucAddressOption)
{
   int           iRet;
   static I2CINFO i2cst;

   /*
    *   Load in a relative Port address for now (1 or 2), the pxi2c.dll will
    *   convert this to an absolute address by reading out of the pxi2c.ini
    *   file. Presently there are only tuners on port one, so it is hard-wired
    *   to be 1.
    */
   i2cst.PortNumber = 1;

   /*
    *   Fill in part of the I2C info structure
    */
   i2cst.address        = ucAddress;
   i2cst.subaddress     = ucSubAddress;
   i2cst.subsubaddress  = NOTUSED;
   i2cst.address_option = ucAddressOption;
   i2cst.regsize        = REGSIZE8BITS;

   iRet = i2c_write((void *)ucTuner, ucNumberBytes, &i2cst);

   /*
    *   Check i2c_write return code.
    */
   if(iRet == I2C_ERROR)
   {
      return (int)TNR_ERR;
   }

   return (int)TNR_OK;
}

/**********************************************************
*
*       Function Name: tnrTunerRead
*
*       Module Abstract:
*       ----------------
*       Read the status byte from the tuner on SDA line of i2c.
*
*       Input Parameters:
*       -----------------
*       *ucTuner
*       ucNumberBytes
*       ucAddress
*       ucSubAddress
*       ucAddressOption
*
*       Output Parameters:
*       ------------------
*       Success = TNR_OK, Fail = TNR_ERR.
*
*       Global Variables:
*       -----------------
*       None
*
***********************************************************
*
*       Author: Frank Xu
*       Date:   08-30-94
*
*       Revision History:
*       -----------------
*       WHO             WHEN            WHAT/WHY/HOW
*       ---             ----            ------------
*
*********************************************************/

int tnrTunerRead(unsigned char *ucTuner,
                 unsigned char ucNumberBytes,
                 unsigned char ucAddress,
                 unsigned char ucSubAddress,
                 unsigned char ucAddressOption)
{
   int           iRet;
   static I2CINFO i2cst;
   unsigned char bTunerStatus;
   /*
    *   Load in a relative Port address for now (1 or 2), the pxi2c.dll will
    *   convert this to an absolute address by reading out of the pxi2c.ini
    *   file. Presently there are only tuners on port one, so it is hard-wired
    *   to be 1.
    */
   i2cst.PortNumber = 1;

   /*
    *   Fill in part of the I2C info structure.
    */
   i2cst.address        = ucAddress;
   i2cst.subaddress     = ucSubAddress;
   i2cst.subsubaddress  = NOTUSED;
   i2cst.address_option = ucAddressOption;
   i2cst.regsize        = REGSIZE8BITS;

   bTunerStatus = 0;
   iRet = i2c_read((unsigned char *) &bTunerStatus, ucNumberBytes, &i2cst);

   /*
    *   Check i2c_read return code.
    */
   if(iRet == I2C_ERROR)
   {
      return(1);
   }

   *ucTuner = bTunerStatus;
   return(0);
}

