/**********************************************************
* Copyright Pixel Semiconductor, 1993. All rights reserved.
***********************************************************
*       File Name:  pxvidapi.h
*
*       Module Abstract:
*       ----------------
*       This module contains the function prototypes and
*       preprocessor definition necessary to communicate
*       with the Video device installable drivers.
*
***********************************************************
*       Author: Kyle Pratt
*       Date:   12-06-93
*
*       Revision History:
*       -----------------
*       WHO             WHEN      WHAT/WHY/HOW
*       ---             ----      ------------
*
***********************************************************/
#ifndef _PXVIDAPI_H
#define _PXVIDAPI_H



/* System #defines ---------------------------------------*/

#define PXVID_MAX_PORTS   2   /* Number of physical video ports */
#define PXVID_PORT1       0
#define PXVID_PORT2       1

/* Video mode defines */
#define PXVID_INPUT     1   /* Used in VIDEO_DEV_CAPS to specify input capable */
#define PXVID_OUTPUT    2   /* Used in VIDEO_DEV_CAPS to specify output capable */
#define PXVID_DUPLEX    4   /* Used in VIDEO_DEV_CAPS to specify duplex capable */

/* Video format defines */
#define PXVID_NTSC      1   /* Used in VIDEO_DEV_CAPS to specify NTSC support */
#define PXVID_PAL       2   /* Used in VIDEO_DEV_CAPS to specify PAL support */
#define PXVID_SECAM     4   /* Used in VIDEO_DEV_CAPS to specify SECAM support */
#define PXVID_CIF       8   /* Used in VIDEO_DEV_CAPS to specify CIF support */
#define PXVID_QCIF   0x10   /* Used in VIDEO_DEV_CAPS to specify QCIF support */
#define PXVID_USER   0x20   /* Used in VIDEO_DEV_CAPS to specify USER DEFINED format support */

/* Input sync source defines */
#define PXVID_ALL_INPUT  0
#define PXVID_ALL_OUTPUT 1

/* Blank type defines */
#define PXVID_HORIZONTAL_BLANK 0
#define PXVID_COMPOSITE_BLANK  1

/* Scan mode defines */
#define PXVID_PROGRESSIVE_SCAN 0
#define PXVID_INTERLACED_SCAN  1

/* Polarity defines */
#define PXVID_ACTIVE_LO 0   /* Specifies a signal is normally hi and pulses low */
#define PXVID_ACTIVE_HI 1   /* Specifies a signal is normally low and pulses hi */

/* Field polarity defines */
#define PXVID_NORMAL_FIELD_POLARITY   0 /* Specifies that hsync/blank is not active on trailing edge of vsync in odd fields */
#define PXVID_INVERTED_FIELD_POLARITY 1 /* Specifies that hsync/blank is active on trailing edge of vsync in odd fields */

/* Device type defines */
#define PXVID_CODEC     1    /* Specifies that the device is a CODEC */
#define PXVID_CCIR      2    /* Specifies that the device is of type CCIR */
#define PXVID_CRTC      4    /* Specifies that the device is CRT controller (ie VGA chip) */

/* Video pass fail code */
#define PXVID_MESSAGE_SUCCESS      1
#define PXVID_MESSAGE_FAILURE      0

/* Video device error codes */
#define PXVIDERR_NONE              0
#define PXVIDERR_GENERAL_FAILURE   1
#define PXVIDERR_NO_SUPPORT        2
#define PXVIDERR_INITIALIZE_FAILURE   3
/* more codes eventually */
#define PXVIDERR_MAX_ERRORS        4

/* typedefs ---------------------------------------------*/

#ifndef _PXVIDEO_H
#define _PXVIDAPI_H
typedef enum tagVideoMode {PCS_IN_ONLY,PCS_OUT_ONLY,PCS_PIXEL_DUPLEX,TESTMODE} VMODE;
typedef enum tagVideoFormat {NTSC,SVHS,PAL,SECAM,CIF,QCIF,USER} VFORMAT;
#endif
typedef enum tagOutSyncSrc {ALL_INPUT, SYNC_IN_BLANK_OUT,ALL_OUT_VSU,ALL_OUT_OPU} OUT_SYNC_SRC;

/*
 * Video device capabilities structure
 *
 * Note that input and output references are with respect to
 * the device connected to the video device (ie PX2070).
 */
typedef struct tagVIDEO_DEV_CAPS
{
  unsigned short wVModeCaps;   /* Defines input, output, duplex capabilities */
  unsigned short wVFormatCaps; /* Defines video standard format */
  unsigned short wXResolutionMax; /* Defines video X resolution maximum*/
  unsigned short wYResolutionMax; /* Defines video Y resolution (Active lines) maximum*/
  unsigned short wSMPTEMax;       /* Defines number of inactive video lines (ie SMPTE info) maximum*/
  unsigned char  bFrameRateMax;   /* Defines video frame rate maximum*/
  unsigned char  bDeviceType;       /* Defines the video device type */
  unsigned char  fBlockMode;        /* Defines if the device supports block mode transfers */
  unsigned char  fStallable;        /* Defines if the device supports stalled transfers */
  unsigned char  fPhaseHiOut;       /* Defines in duplex mode that data is output when phase is hi */
  unsigned char  fPhaseQualified;   /* Defines if video device clocking is phase qualified */
  unsigned char  fHueSupport;       /* Defines if hue adjustments are supported */
  int            iMaxHue;           /* Defines maximum hue value */
  int            iMinHue;           /* Defines minimum hue value */
  unsigned char  fFilterSupport;    /* Defines if sharpness filter adjustments are supported */
  int            iMaxFilter;           /* Defines maximum filter value */
  int            iMinFilter;           /* Defines minimum filter value */
  unsigned char  fSaturationSupport; /* Defines if saturation adjustments are supported */
  int            iMaxSaturation;    /* Defines maximum saturation value */
  int            iMinSaturation;    /* Defines minimum saturation value */
  unsigned char  fContrastSupport;  /* Defines if contrast adjustments are supported */
  int            iMaxContrast;      /* Defines maximum contrast value */
  int            iMinContrast;      /* Defines minimum contrast value */
  unsigned char  fBrightnessSupport; /* Defines if brightness adjustments are supported */
  int            iMaxBrightness;    /* Defines maximum brightness value */
  int            iMinBrightness;    /* Defines minimum brightness value */
  unsigned char  fChannelSelSupport; /* Defines if channel selection is supported */
  int            iMaxChannel;     /* Defines maximum channel value */
  int            iMinChannel;     /* Defines minimum channel value */
  unsigned short wReserved1;      /* Reserved for future use */
  unsigned short wReserved2;      /* Reserved for future use */
  unsigned short wReserved3;      /* Reserved for future use */
  unsigned short wReserved4;      /* Reserved for future use */
  unsigned short wReserved5;      /* Reserved for future use */
} VIDEO_DEV_CAPS;


typedef VIDEO_DEV_CAPS *LPVIDEO_DEV_CAPS;

typedef struct tagCURRENT_VIDEO_PARAMS
{
  VMODE          eVMode;   /* Defines current data flow: input, output, duplex */
  VFORMAT        eVInFormat; /* Defines current video standard format for data input */
  VFORMAT        eVOutFormat; /* Defines current video standard format for data output */
  unsigned short wXResolution; /* Defines video X resolution */
  unsigned short wYResolution; /* Defines video Y resolution (Active lines) */
  unsigned short wSMPTE;       /* Defines number of inactive video lines (ie SMPTE info) */
  unsigned char  bFrameRate;   /* Defines video frame rate */
  unsigned char  fInterlaced;  /* Defines video scanning mode */
  unsigned char  fInputBlankType; /* Defines composite or horizontal blank */
  unsigned char  fInputBlankPol;  /* Defines polarity of Blank when data is input to PX2070 */
  unsigned char  fInputHSyncPol;  /* Defines polarity of HSync when data is input to PX2070 */
  unsigned char  fInputVSyncPol;  /* Defines polarity of VSync when data is input to PX2070 */
  unsigned char  fInputFieldPol;  /* Defines polarity of video field when data is input to PX2070 */
  unsigned char  fInputSyncSource; /* Defines direction of Syncs & Blank when data is input to PX2070 */
  unsigned char  fOutputBlankType; /* Defines composite or horizontal blank */
  unsigned char  fOutputBlankPol;  /* Defines polarity of Blank when data is output from PX2070 */
  unsigned char  fOutputHSyncPol;  /* Defines polarity of HSync when data is output from PX2070 */
  unsigned char  fOutputVSyncPol;  /* Defines polarity of VSync when data is output from PX2070 */
  unsigned char  fOutputFieldPol;  /* Defines polarity of video field when data is output from PX2070 */
  OUT_SYNC_SRC   eOutputSyncSource; /* Defines direction of Syncs & Blank when data is output from PX2070 */
  int            iVideoHue;    /* Defines the current hue setting */
  int            iVideoFilter;  /* Defines the current filter setting */
  int            iVideoSaturation;  /* Defines the current saturation setting */
  int            iVideoContrast;  /* Defines the current contrast setting */
  int            iVideoBrightness;  /* Defines the current brightness setting */
  int            iVideoChannel;    /* Defines the current channel setting */
} CURRENT_VIDEO_PARAMS;
typedef CURRENT_VIDEO_PARAMS *LPCURRENT_VIDEO_PARAMS;

/* Message API -------------------------------------------*/


/*
 * Message: DRV_PXVID_GET_VIDEO_MODE
 * LPARAM1: (LPARAM) (VMODE FAR *) &eVideoMode;
 * LPARAM2: (LPARAM) 0L;
 *
 * LRESULT : Non-zero if successful, or zero if the call failed.  Use
 *           the DRV_PXVID_GET_ERROR message to get the error code for
 *           the failure.
 *
 * This message will return the mode of the current video port. The
 * available modes are specified in the enumerated data type VMODE.
 * The supported modes may be determined by using  the
 * DRV_PXVID_GET_VIDEO_CAPS message.
 */
#define DRV_PXVID_GET_VIDEO_MODE  DRV_RESERVED

/*
 * Message: DRV_PXVID_SET_VIDEO_MODE
 * LPARAM1: (LPARAM) (VMODE) eVideoMode;
 * LPARAM2: (LPARAM) 0L;
 *
 * LRESULT : Non-zero if successful, or zero if the call failed.  Use
 *           the DRV_PXVID_GET_ERROR message to get the error code for
 *           the failure.
 *
 * This message will set the mode of the current video port. The
 * available modes are specified in the enumerated data type VMODE.
 * The supported modes may be determined by using  the
 * DRV_PXVID_GET_VIDEO_CAPS message.
 */
#define DRV_PXVID_SET_VIDEO_MODE  DRV_RESERVED+1

/*
 * Message: DRV_PXVID_GET_VIDEO_INPUT_FORMAT
 * LPARAM1: (LPARAM) (VFORMAT FAR *) &eVideoFormat;
 * LPARAM2: (LPARAM) 0L;
 *
 * LRESULT : Non-zero if successful, or zero if the call failed.  Use
 *           the DRV_PXVID_GET_ERROR message to get the error code for
 *           the failure.
 *
 * This message will return the input format of the current video port. The
 * available modes are specified in the enumerated data type VFORMAT.
 * Note that "input" is in reference to the PX2070, (ie data is being driven
 * into the PX2070).
 *
 */
#define DRV_PXVID_GET_VIDEO_INPUT_FORMAT  DRV_RESERVED+2

/*
 * Message: DRV_PXVID_SET_VIDEO_INPUT_FORMAT
 * LPARAM1: (LPARAM) (VFORMAT) eVideoFormat;
 * LPARAM2: (LPARAM) 0L;
 *
 * LRESULT : Non-zero if successful, or zero if the call failed.  Use
 *           the DRV_PXVID_GET_ERROR message to get the error code for
 *           the failure.
 *
 * This message will set the input format of the current video port. The
 * available modes are specified in the enumerated data type VFORMAT.
 * Note that "input" is in reference to the PX2070, (ie data is being driven
 * into the PX2070).
 *
 */
#define DRV_PXVID_SET_VIDEO_INPUT_FORMAT  DRV_RESERVED+3

/*
 * Message: DRV_PXVID_GET_VIDEO_OUTPUT_FORMAT
 * LPARAM1: (LPARAM) (VFORMAT FAR *) &eVideoFormat;
 * LPARAM2: (LPARAM) 0L;
 *
 * LRESULT : Non-zero if successful, or zero if the call failed.  Use
 *           the DRV_PXVID_GET_ERROR message to get the error code for
 *           the failure.
 *
 * This message will return the output format of the current video port. The
 * available modes are specified in the enumerated data type VFORMAT.
 * Note that "output" is in reference to the PX2070, (ie data is being driven
 * out of the PX2070).
 *
 */
#define DRV_PXVID_GET_VIDEO_OUTPUT_FORMAT  DRV_RESERVED+4

/*
 * Message: DRV_PXVID_SET_VIDEO_OUTPUT_FORMAT
 * LPARAM1: (LPARAM) (VFORMAT) eVideoFormat;
 * LPARAM2: (LPARAM) 0L;
 *
 * LRESULT : Non-zero if successful, or zero if the call failed.  Use
 *           the DRV_PXVID_GET_ERROR message to get the error code for
 *           the failure.
 *
 * This message will set the output format of the current video port. The
 * available modes are specified in the enumerated data type VFORMAT.
 * Note that "output" is in reference to the PX2070, (ie data is being driven
 * out of the PX2070).
 *
 */
#define DRV_PXVID_SET_VIDEO_OUTPUT_FORMAT  DRV_RESERVED+5

/*
 * Message: DRV_PXVID_GET_VIDEO_X_RESOLUTION
 * LPARAM1: (LPARAM) (WORD FAR *) &wVideoXResolution;
 * LPARAM2: (LPARAM) 0L;
 *
 * LRESULT : Non-zero if successful, or zero if the call failed.  Use
 *           the DRV_PXVID_GET_ERROR message to get the error code for
 *           the failure.
 *
 * This message will return the X resolution used on the current video port.
 * The maximum values can be determined by using the
 * DRV_PXVID_GET_DEVICE_CAPS message.
 */
#define DRV_PXVID_GET_VIDEO_X_RESOLUTION  DRV_RESERVED+6

/*
 * Message: DRV_PXVID_SET_VIDEO_X_RESOLUTION
 * LPARAM1: (LPARAM) (WORD) wVideoXResolution;
 * LPARAM2: (LPARAM) 0L;
 *
 * LRESULT : Non-zero if successful, or zero if the call failed.  Use
 *           the DRV_PXVID_GET_ERROR message to get the error code for
 *           the failure.
 *
 * This message will set the X resolution used on the current video port.
 * If the wVideoXResolution parameter exceeds the maximum value specified
 * by the driver, it should be clamped, by the driver, to the maximum.
 * The maximum resolution can be determined by using the DRV_PXVID_GET_
 * DEVICE_CAPS message.
 */
#define DRV_PXVID_SET_VIDEO_X_RESOLUTION  DRV_RESERVED+7

/*
 * Message: DRV_PXVID_GET_VIDEO_Y_RESOLUTION
 * LPARAM1: (LPARAM) (WORD FAR *) &wVideoYResolution;
 * LPARAM2: (LPARAM) 0L;
 *
 * LRESULT : Non-zero if successful, or zero if the call failed.  Use
 *           the DRV_PXVID_GET_ERROR message to get the error code for
 *           the failure.
 *
 * This message will return the Y resolution used on the current video port.
 * The maximum values can be determined by using the
 * DRV_PXVID_GET_DEVICE_CAPS message.
 */
#define DRV_PXVID_GET_VIDEO_Y_RESOLUTION  DRV_RESERVED+8

/*
 * Message: DRV_PXVID_SET_VIDEO_Y_RESOLUTION
 * LPARAM1: (LPARAM) (WORD) wVideoYResolution;
 * LPARAM2: (LPARAM) 0L;
 *
 * LRESULT : Non-zero if successful, or zero if the call failed.  Use
 *           the DRV_PXVID_GET_ERROR message to get the error code for
 *           the failure.
 *
 * This message will set the Y resolution used on the current video port.
 * If the wVideoYResolution parameter exceeds the maximum value specified
 * by the driver, it should be clamped, by the driver, to the maximum.
 * The maximum resolution can be determined by using the DRV_PXVID_GET_
 * DEVICE_CAPS message.
 *
 */
#define DRV_PXVID_SET_VIDEO_Y_RESOLUTION  DRV_RESERVED+9

/*
 * Message: DRV_PXVID_GET_VIDEO_SMPTE
 * LPARAM1: (LPARAM) (WORD FAR *) &wVideoSMPTE;
 * LPARAM2: (LPARAM) 0L;
 *
 * LRESULT : Non-zero if successful, or zero if the call failed.  Use
 *           the DRV_PXVID_GET_ERROR message to get the error code for
 *           the failure.
 *
 * This message will return the number of inactive video lines on the
 * current video port.
 * The maximum values can be determined by using the
 * DRV_PXVID_GET_DEVICE_CAPS message.
 */
#define DRV_PXVID_GET_VIDEO_SMPTE  DRV_RESERVED+10

/*
 * Message: DRV_PXVID_SET_VIDEO_SMPTE
 * LPARAM1: (LPARAM) (WORD) wVideoSMPTE;
 * LPARAM2: (LPARAM) 0L;
 *
 * LRESULT : Non-zero if successful, or zero if the call failed.  Use
 *           the DRV_PXVID_GET_ERROR message to get the error code for
 *           the failure.
 *
 * This message will set the number of inactive video lines on the
 * current video port.
 * If the wVideoSMPTE parameter exceeds the maximum value specified
 * by the driver, it should be clamped, by the driver, to the maximum.
 * The maximum resolution can be determined by using the DRV_PXVID_GET_
 * DEVICE_CAPS message.
 *
 */
#define DRV_PXVID_SET_VIDEO_SMPTE  DRV_RESERVED+11

/*
 * Message: DRV_PXVID_GET_VIDEO_FRAME_RATE
 * LPARAM1: (LPARAM) (BYTE FAR *) &bVideoFrameRate;
 * LPARAM2: (LPARAM) 0L;
 *
 * LRESULT : Non-zero if successful, or zero if the call failed.  Use
 *           the DRV_PXVID_GET_ERROR message to get the error code for
 *           the failure.
 *
 * This message will return the frame rate used on the current video port.
 * The maximum values can be determined by using the
 * DRV_PXVID_GET_DEVICE_CAPS message.
 */
#define DRV_PXVID_GET_VIDEO_FRAME_RATE  DRV_RESERVED+12

/*
 * Message: DRV_PXVID_SET_VIDEO_FRAME_RATE
 * LPARAM1: (LPARAM) (BYTE) bVideoFrameRate;
 * LPARAM2: (LPARAM) 0L;
 *
 * LRESULT : Non-zero if successful, or zero if the call failed.  Use
 *           the DRV_PXVID_GET_ERROR message to get the error code for
 *           the failure.
 *
 * This message will set the frame rate used on the current video port.
 * If the wVideoFrameRate parameter exceeds the maximum value specified
 * by the driver, it should be clamped, by the driver, to the maximum.
 * The maximum resolution can be determined by using the DRV_PXVID_GET_
 * DEVICE_CAPS message.
 *
 */
#define DRV_PXVID_SET_VIDEO_FRAME_RATE  DRV_RESERVED+13

/*
 * Message: DRV_PXVID_GET_VIDEO_SCAN_MODE
 * LPARAM1: (LPARAM) (unsigned char FAR *) &fInterlaced;
 * LPARAM2: (LPARAM) 0L;
 *
 * LRESULT : Non-zero if successful, or zero if the call failed.  Use
 *           the DRV_PXVID_GET_ERROR message to get the error code for
 *           the failure.
 *
 * This message will return the scan mode used on the current video port.
 * A 0 indicates progressive scan. A non-zero indicates interlaced scanning.
 */
#define DRV_PXVID_GET_VIDEO_SCAN_MODE  DRV_RESERVED+14

/*
 * Message: DRV_PXVID_SET_VIDEO_SCAN_MODE
 * LPARAM1: (LPARAM) (unsigned char) fInterlaced;
 * LPARAM2: (LPARAM) 0L;
 *
 * LRESULT : Non-zero if successful, or zero if the call failed.  Use
 *           the DRV_PXVID_GET_ERROR message to get the error code for
 *           the failure.
 *
 * This message will set the scan mode used on the current video port.
 * A 0 indicates progressive scan. A non-zero indicates interlaced scanning.
 *
 */
#define DRV_PXVID_SET_VIDEO_SCAN_MODE  DRV_RESERVED+15

/*
 * Message: DRV_PXVID_GET_VIDEO_HUE
 * LPARAM1: (LPARAM) (INT) &iVideoHue;
 * LPARAM2: (LPARAM) 0L;
 *
 * LRESULT : Non-zero if successful, or zero if the call failed.  Use
 *           the DRV_PXVID_GET_ERROR message to get the error code for
 *           the failure.
 *
 * This message will return the Hue setting of the current video port.
 * The maximum and minimum values can be determined by using the
 * DRV_PXVID_GET_DEVICE_CAPS message.
 */
#define DRV_PXVID_GET_VIDEO_HUE  DRV_RESERVED+16

/*
 * Message: DRV_PXVID_SET_VIDEO_HUE
 * LPARAM1: (LPARAM) (INT) iVideoHue;
 * LPARAM2: (LPARAM) 0L;
 *
 * LRESULT : Non-zero if successful, or zero if the call failed.  Use
 *           the DRV_PXVID_GET_ERROR message to get the error code for
 *           the failure.
 *
 * This message will set the Hue of the current video port.
 * If the input parameter exceeds the maximum value specified
 * by the driver, it should be clamped, by the driver, to the maximum. If the input
 * parameter is less than the minimum value specified by the driver,
 * it should be clamped, by the driver, to the minimum.
 * The maximum and minimum values can be determined by using the
 * DRV_PXVID_GET_DEVICE_CAPS message.
 */
#define DRV_PXVID_SET_VIDEO_HUE  DRV_RESERVED+17

/*
 * Message: DRV_PXVID_GET_VIDEO_FILTER
 * LPARAM1: (LPARAM) (INT FAR *) &iVideoFilter;
 * LPARAM2: (LPARAM) 0L;
 *
 * LRESULT : Non-zero if successful, or zero if the call failed.  Use
 *           the DRV_PXVID_GET_ERROR message to get the error code for
 *           the failure.
 *
 * This message will return the video filter used on the current video port.
 * The maximum and minimum values can be determined by using the
 * DRV_PXVID_GET_DEVICE_CAPS message.
 */
#define DRV_PXVID_GET_VIDEO_FILTER  DRV_RESERVED+18

/*
 * Message: DRV_PXVID_SET_VIDEO_FILTER
 * LPARAM1: (LPARAM) (INT) iVideoFilter;
 * LPARAM2: (LPARAM) 0L;
 *
 * LRESULT : Non-zero if successful, or zero if the call failed.  Use
 *           the DRV_PXVID_GET_ERROR message to get the error code for
 *           the failure.
 *
 * This message will set the video filter on the current video port.
 * If the input parameter exceeds the maximum value specified
 * by the driver, it should be clamped, by the driver, to the maximum. If the input
 * parameter is less than the minimum value specified by the driver,
 * it should be clamped, by the driver, to the minimum.
 * The maximum and minimum values can be determined by using the
 * DRV_PXVID_GET_DEVICE_CAPS message.
 *
 */
#define DRV_PXVID_SET_VIDEO_FILTER  DRV_RESERVED+19

/*
 * Message: DRV_PXVID_GET_VIDEO_SATURATION
 * LPARAM1: (LPARAM) (INT FAR *) &iSaturation;
 * LPARAM2: (LPARAM) 0L;
 *
 * LRESULT : Non-zero if successful, or zero if the call failed.  Use
 *           the DRV_PXVID_GET_ERROR message to get the error code for
 *           the failure.
 *
 * This message will return the saturation value used on the current video port.
 * The maximum and minimum values can be determined by using the
 * DRV_PXVID_GET_DEVICE_CAPS message.
 */
#define DRV_PXVID_GET_VIDEO_SATURATION  DRV_RESERVED+20

/*
 * Message: DRV_PXVID_SET_VIDEO_SATURATION
 * LPARAM1: (LPARAM) (INT) iSaturation;
 * LPARAM2: (LPARAM) 0L;
 *
 * LRESULT : Non-zero if successful, or zero if the call failed.  Use
 *           the DRV_PXVID_GET_ERROR message to get the error code for
 *           the failure.
 *
 * This message will set the saturation value used on the current video port.
 * If the input parameter exceeds the maximum value specified
 * by the driver, it should be clamped, by the driver, to the maximum. If the input
 * parameter is less than the minimum value specified by the driver,
 * it should be clamped, by the driver, to the minimum.
 * The maximum and minimum values can be determined by using the
 * DRV_PXVID_GET_DEVICE_CAPS message.
 *
 */
#define DRV_PXVID_SET_VIDEO_SATURATION  DRV_RESERVED+21

/*
 * Message: DRV_PXVID_GET_VIDEO_CONTRAST
 * LPARAM1: (LPARAM) (INT FAR *) &iContrast;
 * LPARAM2: (LPARAM) 0L;
 *
 * LRESULT : Non-zero if successful, or zero if the call failed.  Use
 *           the DRV_PXVID_GET_ERROR message to get the error code for
 *           the failure.
 *
 * This message will return the contrast value used on the current video port.
 * The maximum and minimum values can be determined by using the
 * DRV_PXVID_GET_DEVICE_CAPS message.
 */
#define DRV_PXVID_GET_VIDEO_CONTRAST  DRV_RESERVED+22

/*
 * Message: DRV_PXVID_SET_VIDEO_CONTRAST
 * LPARAM1: (LPARAM) (INT) iContrast;
 * LPARAM2: (LPARAM) 0L;
 *
 * LRESULT : Non-zero if successful, or zero if the call failed.  Use
 *           the DRV_PXVID_GET_ERROR message to get the error code for
 *           the failure.
 *
 * This message will set the contrast value used on the current video port.
 * If the input parameter exceeds the maximum value specified
 * by the driver, it should be clamped, by the driver, to the maximum. If the input
 * parameter is less than the minimum value specified by the driver,
 * it should be clamped, by the driver, to the minimum.
 * The maximum and minimum values can be determined by using the
 * DRV_PXVID_GET_DEVICE_CAPS message.
 *
 */
#define DRV_PXVID_SET_VIDEO_CONTRAST  DRV_RESERVED+23

/*
 * Message: DRV_PXVID_GET_VIDEO_BRIGHTNESS
 * LPARAM1: (LPARAM) (INT FAR *) &iBrightness;
 * LPARAM2: (LPARAM) 0L;
 *
 * LRESULT : Non-zero if successful, or zero if the call failed.  Use
 *           the DRV_PXVID_GET_ERROR message to get the error code for
 *           the failure.
 *
 * This message will return the brightness value used on the current video port.
 * The maximum and minimum values can be determined by using the
 * DRV_PXVID_GET_DEVICE_CAPS message.
 */
#define DRV_PXVID_GET_VIDEO_BRIGHTNESS  DRV_RESERVED+24

/*
 * Message: DRV_PXVID_SET_VIDEO_BRIGHTNESS
 * LPARAM1: (LPARAM) (INT) iBrightness;
 * LPARAM2: (LPARAM) 0L;
 *
 * LRESULT : Non-zero if successful, or zero if the call failed.  Use
 *           the DRV_PXVID_GET_ERROR message to get the error code for
 *           the failure.
 *
 * This message will set the brightness value used on the current video port.
 * If the input parameter exceeds the maximum value specified
 * by the driver, it should be clamped, by the driver, to the maximum. If the input
 * parameter is less than the minimum value specified by the driver,
 * it should be clamped, by the driver, to the minimum.
 * The maximum and minimum values can be determined by using the
 * DRV_PXVID_GET_DEVICE_CAPS message.
 *
 */
#define DRV_PXVID_SET_VIDEO_BRIGHTNESS  DRV_RESERVED+25

/*
 * Message: DRV_PXVID_GET_VIDEO_CHANNEL
 * LPARAM1: (LPARAM) (INT FAR *) &iVideoChannel;
 * LPARAM2: (LPARAM) 0L;
 *
 * LRESULT : Non-zero if successful, or zero if the call failed.  Use
 *           the DRV_PXVID_GET_ERROR message to get the error code for
 *           the failure.
 *
 * This message will return the input channel used on the current video port.
 * The maximum and minimum values can be determined by using the
 * DRV_PXVID_GET_DEVICE_CAPS message.
 */
#define DRV_PXVID_GET_VIDEO_CHANNEL  DRV_RESERVED+26

/*
 * Message: DRV_PXVID_SET_VIDEO_CHANNEL
 * LPARAM1: (LPARAM) (INT) iVideoChannel;
 * LPARAM2: (LPARAM) 0L;
 *
 * LRESULT : Non-zero if successful, or zero if the call failed.  Use
 *           the DRV_PXVID_GET_ERROR message to get the error code for
 *           the failure.
 *
 * This message will set the input channel used on the current video port.
 * If the input parameter exceeds the maximum value specified
 * by the driver, it should be clamped, by the driver, to the maximum. If the input
 * parameter is less than the minimum value specified by the driver,
 * it should be clamped, by the driver, to the minimum.
 * The maximum and minimum values can be determined by using the
 * DRV_PXVID_GET_DEVICE_CAPS message.
 *
 */
#define DRV_PXVID_SET_VIDEO_CHANNEL  DRV_RESERVED+27


/*
 * Message: DRV_PXVID_GET_CURRENT_VIDEO_PORT
 * LPARAM1: (LPARAM) (INT FAR *) &iVideoPort;
 * LPARAM2: (LPARAM) 0L;
 *
 * LRESULT : Non-zero if successful, or zero if the call failed.  Use
 *           the DRV_PXVID_GET_ERROR message to get the error code for
 *           the failure.
 *
 * This message will return the current video port. In multi-port
 * applications, the value returned indicates the port to which all other
 * messages will communicate.
 */
#define DRV_PXVID_GET_CURRENT_VIDEO_PORT  DRV_RESERVED+28

/*
 * Message: DRV_PXVID_SET_CURRENT_VIDEO_PORT
 * LPARAM1: (LPARAM) (INT) iVideoPort;
 * LPARAM2: (LPARAM) 0L;
 *
 * LRESULT : Non-zero if successful, or zero if the call failed.  Use
 *           the DRV_PXVID_GET_ERROR message to get the error code for
 *           the failure.
 *
 * This message will set the current video port. In multi-port
 * applications, the value specified indicates the port to which all other
 * messages will communicate.
 *
 */
#define DRV_PXVID_SET_CURRENT_VIDEO_PORT  DRV_RESERVED+29

/*
 * Message: DRV_PXVID_INIT_HARDWARE
 * LPARAM1: (LPARAM) 0L;
 * LPARAM2: (LPARAM) 0L;
 *
 * LRESULT : Non-zero if successful, or zero if the call failed.  Use
 *           the DRV_PXVID_GET_ERROR message to get the error code for
 *           the failure.
 *
 * This message will initialize the hardware on the current video port.
 * In multi-port applications, DRV_PXVID_SET_CURRENT_VIDEO_PORT should be
 * used to indicate the port to initialize.
 *
 */
#define DRV_PXVID_INIT_HARDWARE  DRV_RESERVED+30

/*
 * Message: DRV_PXVID_GET_VIDEO_DEVICE_CAPS
 * LPARAM1: (LPARAM) (LPVIDEO_DEV_CAPS) lpVideoDevCaps;
 * LPARAM2: (LPARAM) 0L;
 *
 * LRESULT : Non-zero if successful, or zero if the call failed.  Use
 *           the DRV_PXVID_GET_ERROR message to get the error code for
 *           the failure.
 *
 * This message will fill in the VIDEO_DEV_CAPS structure pointed to
 * by lpVideoDevCaps.
 *
 */
#define DRV_PXVID_GET_VIDEO_DEVICE_CAPS  DRV_RESERVED+31

/*
 * Message: DRV_PXVID_GET_CURRENT_VIDEO_PARAMS
 * LPARAM1: (LPARAM) (LPCURRENT_VIDEO_PARAMS) lpCurrentVideoParams;
 * LPARAM2: (LPARAM) 0L;
 *
 * LRESULT : Non-zero if successful, or zero if the call failed.  Use
 *           the DRV_PXVID_GET_ERROR message to get the error code for
 *           the failure.
 *
 * This message will fill in the CURRENT_VIDEO_PARAMS structure pointed to
 * by lpCurrentVideoParams.
 *
 */
#define DRV_PXVID_GET_CURRENT_VIDEO_PARAMS  DRV_RESERVED+32

/*
 * Message: DRV_PXVID_GET_ERROR
 * LPARAM1: (LPARAM) (DWORD FAR *) lpdwErrorCode;
 * LPARAM2: (LPARAM) 0L;
 *
 * LRESULT : Non-zero if successful, or zero if the call failed.
 *
 * This message will return and clear the current error code of the
 * video port driver.
 */
#define DRV_PXVID_GET_ERROR  DRV_RESERVED+33

/* function prototypes -----------------------------------*/

int  pxdrvSendVideoPortMessage (unsigned short, unsigned short, long, long);


#endif /* _PXVIDDAPI_H */
